---
name: Create an issue
about: 'Post a problem or share an idea'
title: ''
labels: ''
assignees: ''

---

<!-- A short summary of the issue, if appropriate -->


#### Code Sample, a copy-pastable example if possible

A "Minimal, Complete and Verifiable Example" will make it much easier for maintainers to help you:
<http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports>

```python
# Your code here

```

#### Problem description

This should explain **why** the current behaviour is a problem and why the expected output is a better solution.

#### Expected Output
